==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QAbstractFileEngineIterator_shell.h <==
#ifndef QABSTRACTFILEENGINEITERATOR_SHELL_H
#define QABSTRACTFILEENGINEITERATOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCore/private/qabstractfileengine_p.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qfileinfo.h>
#include <QtJambi/RegistryAPI>


class QAbstractFileEngineIterator_shell : public QAbstractFileEngineIterator, public QtJambiShellInterface
{
public:
    QAbstractFileEngineIterator_shell(QDir::Filters filters0, const QStringList& nameFilters1);
    ~QAbstractFileEngineIterator_shell() override;

    QFileInfo currentFileInfo() const override;
    QString currentFileName() const override;
    QString currentFilePath() const override;
    QVariant entryInfo(QAbstractFileEngineIterator::EntryInfoType type0) const override;
    bool hasNext() const override;
    QString next() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractFileEngineIterator_access : public QAbstractFileEngineIterator
{
    jobject __qt_currentFileInfo(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_currentFileName(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_currentFilePath(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_entryInfo_QAbstractFileEngineIterator_EntryInfoType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0) const;
    jboolean __qt_hasNext(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_next(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    static inline const std::type_info& __registerEnumTypeInfo_EntryInfoType() {
        return RegistryAPI::registerEnumTypeInfo<QAbstractFileEngineIterator::EntryInfoType>("QAbstractFileEngineIterator::EntryInfoType", "io/qt/core/internal/QAbstractFileEngineIterator$EntryInfoType");
    }
};

#endif // QABSTRACTFILEENGINEITERATOR_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QAbstractFileEngineIterator_shell.h <==
#ifndef QABSTRACTFILEENGINEITERATOR_SHELL_H
#define QABSTRACTFILEENGINEITERATOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCore/private/qabstractfileengine_p.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qfileinfo.h>
#include <QtJambi/RegistryAPI>


class QAbstractFileEngineIterator_shell : public QAbstractFileEngineIterator, public QtJambiShellInterface
{
public:
    QAbstractFileEngineIterator_shell(QDir::Filters filters0, const QStringList& nameFilters1);
    ~QAbstractFileEngineIterator_shell() override;

    QFileInfo currentFileInfo() const override;
    QString currentFileName() const override;
    QString currentFilePath() const override;
    QVariant entryInfo(QAbstractFileEngineIterator::EntryInfoType type0) const override;
    bool hasNext() const override;
    QString next() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractFileEngineIterator_access : public QAbstractFileEngineIterator
{
    jobject __qt_currentFileInfo_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_currentFileName_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_currentFilePath_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_entryInfo_QAbstractFileEngineIterator_EntryInfoType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0) const;
    jboolean __qt_hasNext_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_next(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    static inline const std::type_info& __registerEnumTypeInfo_EntryInfoType() {
        return RegistryAPI::registerEnumTypeInfo<QAbstractFileEngineIterator::EntryInfoType>("QAbstractFileEngineIterator::EntryInfoType", "io/qt/core/internal/QAbstractFileEngineIterator$EntryInfoType");
    }
};

#endif // QABSTRACTFILEENGINEITERATOR_SHELL_H
